import { BrowserAnimationsModule } from '@angular/platform-browser/animations';
import { BrowserModule } from '@angular/platform-browser';
import { NgZorroAntdModule, NZ_I18N, en_US } from 'ng-zorro-antd';
import { registerLocaleData } from '@angular/common';
import en from '@angular/common/locales/en';
import { FormGroup, FormControl, Validators, FormsModule, ReactiveFormsModule } from '@angular/forms';
import { Component, Input, Output, EventEmitter, ViewEncapsulation, ViewChild, ComponentFactoryResolver, Directive, ViewContainerRef, NgModule } from '@angular/core';
import 'prismjs/prism';
import 'prismjs/components/prism-typescript';
import 'prismjs/components/prism-sql';
import 'prismjs/components/prism-http';

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class NgxAntdJsonSchemaFormComponent {
    constructor() {
        this.schema = [];
        this.settings = this.getDefaultSettings();
        this.schemaChange = new EventEmitter();
        this.submit = new EventEmitter();
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        this.form = this.createGroup(this.schema);
        this.onFormChange();
    }
    /**
     * @param {?} changes
     * @return {?}
     */
    ngOnChanges(changes) {
        if (changes["schema"]) {
            this.schema = changes["schema"]["currentValue"];
            this.form = this.createGroup(this.schema);
            this.onFormChange();
        }
        if (changes["settings"]) {
            /** @type {?} */
            const newSettings = changes["settings"]["currentValue"];
            this.settings = Object.assign(this.settings, newSettings);
        }
    }
    /**
     * @param {?} event
     * @return {?}
     */
    handleSubmit(event) {
        event.preventDefault();
        event.stopPropagation();
        this.submit.emit(this.form.getRawValue());
    }
    /**
     * @return {?}
     */
    onFormChange() {
        this.form.valueChanges.subscribe((/**
         * @param {?} val
         * @return {?}
         */
        val => {
            this.schema.forEach((/**
             * @param {?} item
             * @return {?}
             */
            (item) => {
                if (val[item['key']])
                    item['value'] = val[item['key']];
            }));
            this.schemaChange.emit(this.schema);
        }));
    }
    ;
    /**
     * @param {?} schema
     * @return {?}
     */
    createGroup(schema) {
        /** @type {?} */
        const group = {};
        if (schema) {
            schema.forEach((/**
             * @param {?} item
             * @return {?}
             */
            (item) => {
                /** @type {?} */
                const formState = { value: item.value || "", disabled: item.disabled || false };
                group[item.key] = item.required ? new FormControl(formState, Validators.required) : new FormControl(formState);
            }));
        }
        return new FormGroup(group);
    }
    /**
     * @return {?}
     */
    getDefaultSettings() {
        return JSON.parse(JSON.stringify({
            nzGutter: 8,
            itemClass: "",
            nzSpanLabel: 8,
            labelClass: "",
            nzSpanControl: 16,
            fieldClass: ""
        }));
    }
}
NgxAntdJsonSchemaFormComponent.decorators = [
    { type: Component, args: [{
                selector: "ngx-antd-json-schema-form",
                template: "<form class=\"json-schema-form\" nz-form [formGroup]=\"form\" (submit)=\"handleSubmit($event)\">\n  <ng-container *ngFor=\"let field of schema\" dynamicField [config]=\"field\" [settings]=\"settings\" [group]=\"form\">\n  </ng-container>\n</form>\n",
                encapsulation: ViewEncapsulation.None,
                styles: [".json-form-schema-field.ant-form-item{padding-bottom:0;margin-bottom:0}"]
            }] }
];
/** @nocollapse */
NgxAntdJsonSchemaFormComponent.ctorParameters = () => [];
NgxAntdJsonSchemaFormComponent.propDecorators = {
    schema: [{ type: Input }],
    settings: [{ type: Input }],
    schemaChange: [{ type: Output }],
    submit: [{ type: Output }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class FormButtonComponent {
}
FormButtonComponent.decorators = [
    { type: Component, args: [{
                selector: "json-schema-form-button",
                template: "<nz-form-item\n  class=\"json-form-schema-field json-schema-form-button {{ config.itemClass ? config.itemClass : settings.itemClass }}\"\n  [formGroup]=\"group\"\n  nz-row\n  [nzGutter]=\"config.nzGutter ? config.nzGutter : settings.nzGutter\"\n  nzFlex\n>\n  <nz-form-control\n    nz-col\n    [nzSpan]=\"config.nzSpanControl ? config.nzSpanControl : settings.nzSpanControl\"\n    [nzOffset]=\"config.nzSpanLabel ? config.nzSpanLabel : settings.nzSpanLabel\"\n  >\n    <button\n      nz-button\n      nzType=\"primary\"\n      [disabled]=\"config.disabled\"\n      type=\"submit\"\n      [ngClass]=\"config.fieldClass ? config.fieldClass : settings.fieldClass\"\n    >\n      {{ config.label }}\n    </button>\n  </nz-form-control>\n</nz-form-item>\n",
                styles: [".json-form-schema-field.ant-form-item{padding-bottom:0;margin-bottom:0}"]
            }] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class FormInputComponent {
}
FormInputComponent.decorators = [
    { type: Component, args: [{
                selector: "json-schema-form-input",
                template: "<nz-form-item\n  class=\"json-form-schema-field {{ config.itemClass ? config.itemClass : settings.itemClass }}\"\n  [formGroup]=\"group\"\n  nz-row\n  [nzGutter]=\"config.nzGutter ? config.nzGutter : settings.nzGutter\"\n  nzFlex\n>\n  <nz-form-label\n    nz-col\n    [nzSpan]=\"config.nzSpanLabel ? config.nzSpanLabel : settings.nzSpanLabel\"\n    [nzRequired]=\"config.required\"\n    [nzFor]=\"config.key\"\n    [ngClass]=\"config.labelClass ? config.labelClass : settings.labelClass\"\n  >\n    <span [innerHTML]=\"config.label\"></span>\n  </nz-form-label>\n  <nz-form-control nz-col [nzSpan]=\"config.nzSpanControl ? config.nzSpanControl : settings.nzSpanControl\">\n    <input\n      nz-input\n      [readonly]=\"config.readonly\"\n      [formControlName]=\"config.key\"\n      [id]=\"config.key\"\n      [placeholder]=\"config.placeholder || config.label\"\n      [ngClass]=\"config.fieldClass ? config.fieldClass : settings.fieldClass\"\n    />\n    <nz-form-explain *ngIf=\"group.get(config.key).dirty && group.get(config.key).errors\">\n      Please enter {{ config.label }}\n    </nz-form-explain>\n  </nz-form-control>\n</nz-form-item>\n",
                styles: [".json-form-schema-field.ant-form-item{padding-bottom:0;margin-bottom:0}"]
            }] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class FormCheckboxComponent {
}
FormCheckboxComponent.decorators = [
    { type: Component, args: [{
                selector: "json-schema-form-checkbox",
                template: "<nz-form-item\n  class=\"json-form-schema-field {{ config.itemClass ? config.itemClass : settings.itemClass }}\"\n  [formGroup]=\"group\"\n  nz-row\n  [nzGutter]=\"config.nzGutter ? config.nzGutter : settings.nzGutter\"\n  nzFlex\n>\n  <nz-form-label\n    nz-col\n    [nzSpan]=\"config.nzSpanLabel ? config.nzSpanLabel : settings.nzSpanLabel\"\n    [nzRequired]=\"config.required\"\n    [nzFor]=\"config.key\"\n    [ngClass]=\"config.labelClass ? config.labelClass : settings.labelClass\"\n  >\n    {{ config.label }}\n  </nz-form-label>\n  <nz-form-control nz-col [nzSpan]=\"config.nzSpanControl ? config.nzSpanControl : settings.nzSpanControl\">\n    <label\n      nz-checkbox\n      [formControlName]=\"config.key\"\n      [ngModel]=\"config.value\"\n      [ngClass]=\"config.fieldClass ? config.fieldClass : settings.fieldClass\"\n    >\n    </label>\n  </nz-form-control>\n</nz-form-item>\n",
                styles: [".json-form-schema-field.ant-form-item{padding-bottom:0;margin-bottom:0}"]
            }] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class FormSelectComponent {
}
FormSelectComponent.decorators = [
    { type: Component, args: [{
                selector: "json-schema-form-select",
                template: "<nz-form-item\n  class=\"json-form-schema-field {{ config.itemClass ? config.itemClass : settings.itemClass }}\"\n  [formGroup]=\"group\"\n  nz-row\n  [nzGutter]=\"config.nzGutter ? config.nzGutter : settings.nzGutter\"\n  nzFlex\n>\n  <nz-form-label\n    nz-col\n    [nzSpan]=\"config.nzSpanLabel ? config.nzSpanLabel : settings.nzSpanLabel\"\n    [nzRequired]=\"config.required\"\n    [nzFor]=\"config.key\"\n    [ngClass]=\"config.labelClass ? config.labelClass : settings.labelClass\"\n  >\n    <span [innerHTML]=\"config.label\"></span>\n  </nz-form-label>\n  <nz-form-control nz-col [nzSpan]=\"config.nzSpanControl ? config.nzSpanControl : settings.nzSpanControl\">\n    <nz-select\n      style=\"width: 120px;\"\n      [formControlName]=\"config.key\"\n      [(ngModel)]=\"config.value\"\n      nzAllowClear\n      [nzPlaceHolder]=\"config.placeholder || config.label\"\n      [ngClass]=\"config.fieldClass ? config.fieldClass : settings.fieldClass\"\n    >\n      <nz-option\n        *ngFor=\"let option of config.options\"\n        [nzValue]=\"option.value\"\n        [nzLabel]=\"option.label\"\n        [nzDisabled]=\"option.disabled\"\n      >\n      </nz-option>\n    </nz-select>\n    <nz-form-explain *ngIf=\"group.get(config.key).dirty && group.get(config.key).errors\">\n      Please choose an option\n    </nz-form-explain>\n  </nz-form-control>\n</nz-form-item>\n",
                styles: [".json-form-schema-field.ant-form-item{padding-bottom:0;margin-bottom:0}"]
            }] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class FormTextareaComponent {
}
FormTextareaComponent.decorators = [
    { type: Component, args: [{
                selector: "json-schema-form-textarea",
                template: "<nz-form-item\n  class=\"json-form-schema-field {{ config.itemClass ? config.itemClass : settings.itemClass }}\"\n  [formGroup]=\"group\"\n  nz-row\n  [nzGutter]=\"config.nzGutter ? config.nzGutter : settings.nzGutter\"\n  nzFlex\n>\n  <nz-form-label\n    nz-col\n    [nzSpan]=\"config.nzSpanLabel ? config.nzSpanLabel : settings.nzSpanLabel\"\n    [nzRequired]=\"config.required\"\n    [nzFor]=\"config.key\"\n    [ngClass]=\"config.labelClass ? config.labelClass : settings.labelClass\"\n  >\n    {{ config.label }}\n  </nz-form-label>\n  <nz-form-control nz-col [nzSpan]=\"config.nzSpanControl ? config.nzSpanControl : settings.nzSpanControl\">\n    <textarea\n      rows=\"6\"\n      nz-input\n      [readonly]=\"config.readonly\"\n      [formControlName]=\"config.key\"\n      [id]=\"config.key\"\n      [placeholder]=\"config.placeholder || config.label\"\n      [ngClass]=\"config.fieldClass ? config.fieldClass : settings.fieldClass\"\n    ></textarea>\n    <nz-form-explain *ngIf=\"group.get(config.key).dirty && group.get(config.key).errors\">\n      Please input your username!\n    </nz-form-explain>\n  </nz-form-control>\n</nz-form-item>\n",
                styles: [".json-form-schema-field.ant-form-item{padding-bottom:0;margin-bottom:0}"]
            }] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class PrismComponent {
    constructor() { }
    /**
     * @return {?}
     */
    onContentChanged() {
        this.codeViewChild.nativeElement.innerHTML = this.config.value
            ? this.encodeEntities(this.config.value)
            : this.rawViewChild.nativeElement.innerHTML;
        Prism.highlightElement(this.codeViewChild.nativeElement);
    }
    /**
     * @return {?}
     */
    ngAfterViewInit() {
        this.onContentChanged();
    }
    /**
     * @return {?}
     */
    ngOnChanges() {
        this.onContentChanged();
    }
    /**
     * @return {?}
     */
    ngAfterContentInit() {
        this.observer = new MutationObserver(this.onContentChanged.bind(this));
        this.observer.observe(this.rawViewChild.nativeElement, {
            characterData: true,
            childList: true,
            subtree: true
        });
    }
    /**
     * @return {?}
     */
    ngOnDestroy() {
        if (this.observer) {
            this.observer.disconnect();
        }
    }
    /**
     * @param {?} value
     * @return {?}
     */
    encodeEntities(value) {
        return value
            .replace(/&/g, "&amp;")
            .replace(/"/g, "&quot;")
            .replace(/'/g, "&#39;")
            .replace(/</g, "&lt;")
            .replace(/>/g, "&gt;");
    }
}
PrismComponent.decorators = [
    { type: Component, args: [{
                selector: "form-prism",
                template: "<nz-form-item\n  class=\"json-form-schema-field {{ config.itemClass ? config.itemClass : settings.itemClass }}\"\n  [formGroup]=\"group\"\n  nz-row\n  [nzGutter]=\"config.nzGutter ? config.nzGutter : settings.nzGutter\"\n  nzFlex\n>\n  <nz-form-label\n    nz-col\n    [nzSpan]=\"config.nzSpanLabel ? config.nzSpanLabel : settings.nzSpanLabel\"\n    [nzRequired]=\"config.required\"\n    [nzFor]=\"config.key\"\n    [ngClass]=\"config.labelClass ? config.labelClass : settings.labelClass\"\n  >\n    {{ config.label }}\n  </nz-form-label>\n  <nz-form-control nz-col [nzSpan]=\"config.nzSpanControl ? config.nzSpanControl : settings.nzSpanControl\">\n    <div hidden #raw style=\"display: none\">\n      <ng-content></ng-content>\n    </div>\n    <pre class=\"prism-pre\" [ngClass]=\"config.fieldClass ? config.fieldClass : settings.fieldClass\">\n      <code class=\"prism-code language-{{config.language}}\" #code></code>\n    </pre>\n  </nz-form-control>\n</nz-form-item>\n",
                styles: [".json-form-schema-field.ant-form-item{padding-bottom:0;margin-bottom:0}pre.prism-pre{white-space:inherit}code.prism-code{word-break:break-all;white-space:pre-wrap}"]
            }] }
];
/** @nocollapse */
PrismComponent.ctorParameters = () => [];
PrismComponent.propDecorators = {
    rawViewChild: [{ type: ViewChild, args: ["raw",] }],
    codeViewChild: [{ type: ViewChild, args: ["code",] }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @type {?} */
const components = {
    button: FormButtonComponent,
    string: FormInputComponent,
    select: FormSelectComponent,
    bool: FormCheckboxComponent,
    text: FormTextareaComponent,
    prism: PrismComponent
};
class DynamicFieldDirective {
    /**
     * @param {?} resolver
     * @param {?} container
     */
    constructor(resolver, container) {
        this.resolver = resolver;
        this.container = container;
    }
    /**
     * @return {?}
     */
    get isValid() {
        return this.group.controls[this.config.key].valid;
    }
    /**
     * @return {?}
     */
    ngOnChanges() {
        if (this.component) {
            this.component.instance.group = this.group;
            this.component.instance.config = this.config;
            this.component.instance.settings = this.settings;
        }
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        if (!components[this.config.type]) {
            /** @type {?} */
            const supportedTypes = Object.keys(components).join(", ");
            throw new Error(`Trying to use an unsupported type (${this.config.type}).
        Supported types: ${supportedTypes}`);
        }
        /** @type {?} */
        const component = this.resolver.resolveComponentFactory(components[this.config.type]);
        this.component = this.container.createComponent(component);
        this.component.instance.group = this.group;
        this.component.instance.config = this.config;
        this.component.instance.settings = this.settings;
    }
}
DynamicFieldDirective.decorators = [
    { type: Directive, args: [{
                selector: "[dynamicField]"
            },] }
];
/** @nocollapse */
DynamicFieldDirective.ctorParameters = () => [
    { type: ComponentFactoryResolver },
    { type: ViewContainerRef }
];
DynamicFieldDirective.propDecorators = {
    group: [{ type: Input }],
    config: [{ type: Input }],
    settings: [{ type: Input }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
registerLocaleData(en);
/** @type {?} */
const childComponents = [
    FormButtonComponent,
    FormInputComponent,
    FormSelectComponent,
    FormCheckboxComponent,
    FormTextareaComponent,
    PrismComponent
];
const ɵ0 = en_US;
class NgxAntdJsonSchemaFormModule {
}
NgxAntdJsonSchemaFormModule.decorators = [
    { type: NgModule, args: [{
                declarations: [NgxAntdJsonSchemaFormComponent, DynamicFieldDirective, ...childComponents],
                imports: [BrowserModule, NgZorroAntdModule, FormsModule, ReactiveFormsModule, BrowserAnimationsModule],
                providers: [{ provide: NZ_I18N, useValue: ɵ0 }],
                entryComponents: childComponents,
                exports: [NgxAntdJsonSchemaFormComponent]
            },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

export { NgxAntdJsonSchemaFormComponent, NgxAntdJsonSchemaFormModule, FormButtonComponent as ɵb, FormCheckboxComponent as ɵe, FormInputComponent as ɵc, PrismComponent as ɵg, FormSelectComponent as ɵd, FormTextareaComponent as ɵf, DynamicFieldDirective as ɵa };

//# sourceMappingURL=ngx-antd-json-schema-form.js.map